@@ -65,6 +65,7 @@ from pex.resolve.resolvers import (
     check_resolve,
 )
 from pex.resolve.target_system import TargetSystem, UniversalTarget
+from pex.result import Error
 from pex.targets import AbbreviatedPlatform, CompletePlatform, LocalInterpreter, Target, Targets
 from pex.third_party.packaging.specifiers import SpecifierSet
 from pex.third_party.packaging.tags import Tag
@@ -309,10 +310,7 @@ class _PipSession(object):
             if isinstance(requirement, LocalProjectRequirement):
                 for request in self.requests:
                     yield BuildRequest.for_directory(
-                        target=request.target,
-                        source_path=requirement.path,
-                        resolver=self.resolver,
-                        pip_version=self.pip_version,
+                        target=request.target, source_path=requirement.path
                     )
 
     def generate_reports(self, max_parallel_jobs=None):
@@ -594,12 +592,17 @@ def _fingerprint_directory(path):
     return CacheHelper.dir_hash(path, digest=_hasher())
 
 
+class BuildError(Exception):
+    pass
+
+
 def _fingerprint_local_project(
     path,  # type: str
     target,  # type: Target
     resolver=None,  # type: Optional[Resolver]
     pip_version=None,  # type: Optional[PipVersionValue]
 ):
+    # type: (...) -> str
     if resolver:
         build_system_resolver = resolver
     else:
@@ -607,17 +610,20 @@ def _fingerprint_local_project(
 
         build_system_resolver = ConfiguredResolver.default()
 
-    return digest_local_project(
+    hasher = _hasher()
+    result = digest_local_project(
         directory=path,
-        digest=_hasher(),
+        digest=hasher,
         target=target,
         resolver=build_system_resolver,
         pip_version=pip_version,
     )
-
-
-class BuildError(Exception):
-    pass
+    if isinstance(result, Error):
+        raise BuildError(
+            "Failed to create an sdist for hashing from the local project at {path}: "
+            "{err}".format(path=path, err=result)
+        )
+    return hasher.hexdigest()
 
 
 def _as_download_target(target):
@@ -649,27 +655,19 @@ class BuildRequest(object):
         target,  # type: Union[DownloadTarget, Target]
         source_path,  # type: str
         subdirectory=None,  # type: Optional[str]
-        resolver=None,  # type: Optional[Resolver]
-        pip_version=None,  # type: Optional[PipVersionValue]
     ):
         # type: (...) -> BuildRequest
         download_target = _as_download_target(target)
-        fingerprint = _fingerprint_local_project(
-            path=source_path,
-            target=download_target.target,
-            resolver=resolver,
-            pip_version=pip_version,
-        )
         return cls(
             download_target=download_target,
             source_path=source_path,
-            fingerprint=fingerprint,
+            fingerprint=None,
             subdirectory=subdirectory,
         )
 
     download_target = attr.ib(converter=_as_download_target)  # type: DownloadTarget
     source_path = attr.ib()  # type: str
-    fingerprint = attr.ib()  # type: str
+    fingerprint = attr.ib()  # type: Optional[str]
     subdirectory = attr.ib()  # type: Optional[str]
 
     @property
@@ -724,12 +722,16 @@ class BuildResult(object):
         source_path=None,  # type: Optional[str]
     ):
         # type: (...) -> BuildResult
-        built_wheel = BuiltWheelDir.create(
-            sdist=source_path or build_request.source_path,
-            fingerprint=build_request.fingerprint,
-            target=build_request.target,
-        )
-        return cls(request=build_request, atomic_dir=AtomicDirectory(built_wheel.dist_dir))
+        if build_request.fingerprint:
+            built_wheel = BuiltWheelDir.create(
+                sdist=source_path or build_request.source_path,
+                fingerprint=build_request.fingerprint,
+                target=build_request.target,
+            )
+            target_dir = built_wheel.dist_dir
+        else:
+            target_dir = os.path.join(safe_mkdtemp(), "build")
+        return cls(request=build_request, atomic_dir=AtomicDirectory(target_dir))
 
     request = attr.ib()  # type: BuildRequest
     _atomic_dir = attr.ib()  # type: AtomicDirectory
@@ -1290,14 +1292,7 @@ class BuildAndInstallRequest(object):
                 if is_wheel(dist_path):
                     to_install.add(InstallRequest.create(install_request.target, dist_path))
                 elif os.path.isdir(dist_path):
-                    to_build.add(
-                        BuildRequest.for_directory(
-                            install_request.target,
-                            dist_path,
-                            resolver=self._resolver,
-                            pip_version=self._pip_version,
-                        )
-                    )
+                    to_build.add(BuildRequest.for_directory(install_request.target, dist_path))
                 else:
                     to_build.add(BuildRequest.for_file(install_request.target, dist_path))
             already_analyzed.add(metadata.project_name)
@@ -1907,11 +1902,21 @@ def download_requests(
     def add_build_requests(requests):
         # type: (Iterable[BuildRequest]) -> None
         for request in requests:
+            if request.fingerprint:
+                fingerprint = request.fingerprint
+            else:
+                production_assert(os.path.isdir(request.source_path))
+                fingerprint = _fingerprint_local_project(
+                    path=request.source_path,
+                    target=request.target,
+                    resolver=resolver,
+                    pip_version=pip_version,
+                )
             local_distributions.append(
                 LocalDistribution(
                     download_target=request.download_target,
                     path=request.source_path,
-                    fingerprint=request.fingerprint,
+                    fingerprint=fingerprint,
                     subdirectory=request.subdirectory,
                 )
             )
