@@ -1,11 +1,10 @@
-# Copyright 2021 Pants project contributors (see CONTRIBUTORS.md).
+# Copyright 2021 Pex project contributors.
 # Licensed under the Apache License, Version 2.0 (see LICENSE).
 
 import os
-import subprocess
 
 from pex.common import safe_copy, temporary_dir
-from pex.testing import built_wheel, make_env, make_source_dir, run_pex_command
+from testing import built_wheel, make_env, make_source_dir, run_pex_command, subprocess
 
 
 def test_requirement_setup_py_with_extras():
