@@ -1,4 +1,4 @@
-# Copyright 2021 Pants project contributors (see CONTRIBUTORS.md).
+# Copyright 2021 Pex project contributors.
 # Licensed under the Apache License, Version 2.0 (see LICENSE).
 
 import itertools
@@ -10,18 +10,21 @@ from argparse import ArgumentParser, ArgumentTypeError
 import pytest
 
 import pex.resolve.target_configuration
+from pex.common import environment_as
 from pex.interpreter import PythonInterpreter
 from pex.pep_425 import CompatibilityTags
 from pex.pep_508 import MarkerEnvironment
 from pex.platforms import Platform
-from pex.resolve import target_options
+from pex.resolve import abbreviated_platforms, target_options
+from pex.resolve.resolver_configuration import PipConfiguration
+from pex.resolve.target_configuration import InterpreterConstraintsNotSatisfied
 from pex.targets import CompletePlatform, Targets
-from pex.testing import IS_MAC, environment_as
 from pex.typing import TYPE_CHECKING
 from pex.variables import ENV
+from testing import IS_MAC
 
 if TYPE_CHECKING:
-    from typing import Any, Iterable, List, Optional, Tuple
+    from typing import Any, Dict, Iterable, List, Optional, Tuple, Type
 
 
 def compute_target_configuration(
@@ -30,20 +33,18 @@ def compute_target_configuration(
 ):
     # type: (...) -> Targets
     options = parser.parse_args(args=args)
-    return target_options.configure(options).resolve_targets()
+    return target_options.configure(options, pip_configuration=PipConfiguration()).resolve_targets()
 
 
 def test_clp_manylinux(parser):
     # type: (ArgumentParser) -> None
     target_options.register(parser)
 
-    targets = compute_target_configuration(parser, args=[])
-    assert targets.assume_manylinux, "The --manylinux option should default to some value."
+    assert compute_target_configuration(parser, args=[]) is not None
 
     def assert_manylinux(value):
         # type: (str) -> None
-        rc = compute_target_configuration(parser, args=["--manylinux", value])
-        assert value == rc.assume_manylinux
+        assert compute_target_configuration(parser, args=["--manylinux", value]) is not None
 
     # Legacy manylinux standards should be supported.
     assert_manylinux("manylinux1_x86_64")
@@ -54,8 +55,7 @@ def test_clp_manylinux(parser):
     assert_manylinux("manylinux_2_5_x86_64")
     assert_manylinux("manylinux_2_33_x86_64")
 
-    targets = compute_target_configuration(parser, args=["--no-manylinux"])
-    assert targets.assume_manylinux is None
+    assert compute_target_configuration(parser, args=["--no-manylinux"]) is not None
 
     with pytest.raises(ArgumentTypeError):
         compute_target_configuration(parser, args=["--manylinux", "foo"])
@@ -80,12 +80,16 @@ def test_configure_platform(parser):
     # The special 'current' platform should map to a `None` platform entry.
     assert_platforms(["current"], None)
 
-    assert_platforms(["linux-x86_64-cp-37-cp37m"], Platform.create("linux-x86_64-cp-37-cp37m"))
-    assert_platforms(["linux-x86_64-cp-37-m"], Platform.create("linux-x86_64-cp-37-cp37m"))
+    assert_platforms(
+        ["linux-x86_64-cp-37-cp37m"], abbreviated_platforms.create("linux-x86_64-cp-37-cp37m")
+    )
+    assert_platforms(
+        ["linux-x86_64-cp-37-m"], abbreviated_platforms.create("linux-x86_64-cp-37-cp37m")
+    )
     assert_platforms(
         ["linux-x86_64-cp-37-m", "macosx-10.13-x86_64-cp-36-cp36m"],
-        Platform.create("linux-x86_64-cp-37-cp37m"),
-        Platform.create("macosx-10.13-x86_64-cp-36-m"),
+        abbreviated_platforms.create("linux-x86_64-cp-37-cp37m"),
+        abbreviated_platforms.create("macosx-10.13-x86_64-cp-36-m"),
     )
 
 
@@ -232,57 +236,57 @@ def path_for(*interpreters):
 def test_configure_interpreter_path(
     parser,  # type: ArgumentParser
     py27,  # type: PythonInterpreter
-    py37,  # type: PythonInterpreter
-    py310,  # type: PythonInterpreter
+    py39,  # type: PythonInterpreter
+    py311,  # type: PythonInterpreter
 ):
     # type: (...) -> None
     target_options.register(parser)
 
-    with environment_as(PATH=path_for(py27, py37, py310)):
+    with environment_as(PATH=path_for(py27, py39, py311)):
         assert_interpreter(parser, ["--python", "python"], py27)
         assert_interpreter(parser, ["--python", "python2"], py27)
-        assert_interpreter(parser, ["--python", "python3"], py37)
-        assert_interpreter(parser, ["--python", "python3.10"], py310)
+        assert_interpreter(parser, ["--python", "python3"], py39)
+        assert_interpreter(parser, ["--python", "python3.11"], py311)
         with pytest.raises(pex.resolve.target_configuration.InterpreterNotFound):
-            compute_target_configuration(parser, args=["--python", "python3.9"])
+            compute_target_configuration(parser, args=["--python", "python3.10"])
 
 
 def test_configure_interpreter_pex_python_path(
     parser,  # type: ArgumentParser
     py27,  # type: PythonInterpreter
-    py37,  # type: PythonInterpreter
-    py310,  # type: PythonInterpreter
+    py39,  # type: PythonInterpreter
+    py311,  # type: PythonInterpreter
 ):
     # type: (...) -> None
     target_options.register(parser)
 
-    path_env_var = path_for(py27, py37, py310)
+    path_env_var = path_for(py27, py39, py311)
 
     with ENV.patch(PEX_PYTHON_PATH=path_env_var):
         assert_interpreter(parser, ["--python", "python"], py27)
         assert_interpreter(parser, ["--python", "python2"], py27)
-        assert_interpreter(parser, ["--python", "python3"], py37)
-        assert_interpreter(parser, ["--python", "python3.10"], py310)
+        assert_interpreter(parser, ["--python", "python3"], py39)
+        assert_interpreter(parser, ["--python", "python3.11"], py311)
         with pytest.raises(pex.resolve.target_configuration.InterpreterNotFound):
-            compute_target_configuration(parser, args=["--python", "python3.9"])
+            compute_target_configuration(parser, args=["--python", "python3.10"])
 
     with ENV.patch(PEX_PYTHON_PATH=py27.binary):
         assert_interpreter(parser, ["--python", "python2.7"], py27)
 
-    assert_interpreter(parser, ["--python-path", path_env_var, "--python", "python3"], py37)
-    assert_interpreter(parser, ["--python-path", py310.binary, "--python", "python3.10"], py310)
+    assert_interpreter(parser, ["--python-path", path_env_var, "--python", "python3"], py39)
+    assert_interpreter(parser, ["--python-path", py311.binary, "--python", "python3.11"], py311)
 
 
 def test_configure_interpreter_constraints(
     parser,  # type: ArgumentParser
     py27,  # type: PythonInterpreter
-    py37,  # type: PythonInterpreter
-    py310,  # type: PythonInterpreter
+    py39,  # type: PythonInterpreter
+    py311,  # type: PythonInterpreter
 ):
     # type: (...) -> None
     target_options.register(parser)
 
-    path_env_var = path_for(py310, py27, py37)
+    path_env_var = path_for(py311, py27, py39)
 
     def interpreter_constraint_args(interpreter_constraints):
         # type: (Iterable[str]) -> List[str]
@@ -307,37 +311,46 @@ def test_configure_interpreter_constraints(
             *expected_interpreters
         )
 
-    assert_interpreter_constraint(["CPython"], [py310, py27, py37], expected_interpreter=py27)
-    assert_interpreter_constraint([">=2"], [py310, py27, py37], expected_interpreter=py27)
-    assert_interpreter_constraint([">=2,!=3.7.*"], [py310, py27], expected_interpreter=py27)
-    assert_interpreter_constraint(["==3.*"], [py310, py37], expected_interpreter=py37)
-    assert_interpreter_constraint(["==3.10.*"], [py310], expected_interpreter=py310)
-    assert_interpreter_constraint([">3"], [py310, py37], expected_interpreter=py37)
-    assert_interpreter_constraint([">=3.7,<3.8"], [py37], expected_interpreter=py37)
-    assert_interpreter_constraint(["==3.10.*", "==2.7.*"], [py310, py27], expected_interpreter=py27)
+    assert_interpreter_constraint(["CPython"], [py311, py27, py39], expected_interpreter=py27)
+    assert_interpreter_constraint([">=2"], [py311, py27, py39], expected_interpreter=py27)
+    assert_interpreter_constraint([">=2,!=3.9.*"], [py311, py27], expected_interpreter=py27)
+    assert_interpreter_constraint(["==3.*"], [py311, py39], expected_interpreter=py39)
+    assert_interpreter_constraint(["==3.11.*"], [py311], expected_interpreter=py311)
+    assert_interpreter_constraint([">3"], [py311, py39], expected_interpreter=py39)
+    assert_interpreter_constraint([">=3.9,<3.10"], [py39], expected_interpreter=py39)
+    assert_interpreter_constraint(["==3.11.*", "==2.7.*"], [py311, py27], expected_interpreter=py27)
 
-    def assert_interpreter_constraint_not_satisfied(interpreter_constraints):
-        # type: (List[str]) -> None
-        with pytest.raises(pex.resolve.target_configuration.InterpreterConstraintsNotSatisfied):
+    def assert_interpreter_constraint_not_satisfied(
+        interpreter_constraints,  # type: List[str]
+        expected_error_type,  # type: Type[Exception]
+    ):
+        # type: (...) -> None
+        with pytest.raises(expected_error_type):
             compute_target_configuration(
                 parser, interpreter_constraint_args(interpreter_constraints)
             )
 
-    assert_interpreter_constraint_not_satisfied(["==3.9.*"])
-    assert_interpreter_constraint_not_satisfied(["==3.8.*,!=3.8.*"])
-    assert_interpreter_constraint_not_satisfied(["==3.9.*", "==2.6.*"])
+    assert_interpreter_constraint_not_satisfied(
+        ["==3.10.*"], expected_error_type=InterpreterConstraintsNotSatisfied
+    )
+    assert_interpreter_constraint_not_satisfied(
+        ["==3.9.*,!=3.9.*"], expected_error_type=ArgumentTypeError
+    )
+    assert_interpreter_constraint_not_satisfied(
+        ["==3.10.*", "==2.6.*"], expected_error_type=InterpreterConstraintsNotSatisfied
+    )
 
 
 def test_configure_resolve_local_platforms(
     parser,  # type: ArgumentParser
     py27,  # type: PythonInterpreter
-    py37,  # type: PythonInterpreter
-    py310,  # type: PythonInterpreter
+    py39,  # type: PythonInterpreter
+    py311,  # type: PythonInterpreter
 ):
     # type: (...) -> None
     target_options.register(parser)
 
-    path_env_var = path_for(py27, py37, py310)
+    path_env_var = path_for(py27, py39, py311)
 
     def assert_local_platforms(
         platforms,  # type: Iterable[str]
@@ -351,7 +364,10 @@ def test_configure_resolve_local_platforms(
         args.extend(itertools.chain.from_iterable(("--platform", p) for p in platforms))
         args.extend(extra_args or ())
         targets = compute_target_configuration(parser, args)
-        assert tuple(Platform.create(ep) for ep in expected_platforms) == targets.platforms
+        assert (
+            tuple(abbreviated_platforms.create(ep) for ep in expected_platforms)
+            == targets.platforms
+        )
         assert_interpreters_configured(targets, expected_interpreter, expected_interpreters)
 
     assert_local_platforms(
@@ -363,23 +379,184 @@ def test_configure_resolve_local_platforms(
     foreign_platform = "linux-x86_64-cp-37-m" if IS_MAC else "macosx-10.13-x86_64-cp-37-m"
 
     assert_local_platforms(
-        platforms=[foreign_platform, str(py37.platform)],
+        platforms=[foreign_platform, str(py39.platform)],
         expected_platforms=[foreign_platform],
-        expected_interpreter=py37,
+        expected_interpreter=py39,
     )
 
     assert_local_platforms(
-        platforms=[foreign_platform, str(py37.platform)],
+        platforms=[foreign_platform, str(py39.platform)],
         extra_args=["--interpreter-constraint", "CPython"],
         expected_platforms=[foreign_platform],
         expected_interpreter=py27,
-        expected_interpreters=(py27, py37, py310),
+        expected_interpreters=(py27, py39, py311),
     )
 
     assert_local_platforms(
         platforms=[foreign_platform, str(py27.platform)],
-        extra_args=["--interpreter-constraint", "==3.10.*"],
+        extra_args=["--interpreter-constraint", "==3.11.*"],
         expected_platforms=[foreign_platform],
         expected_interpreter=py27,
-        expected_interpreters=(py310, py27),
+        expected_interpreters=(py311, py27),
+    )
+
+
+def test_configure_resolve_local_platforms_with_complete_platforms(
+    tmpdir,  # type: Any
+    parser,  # type: ArgumentParser
+    py27,  # type: PythonInterpreter
+    py39,  # type: PythonInterpreter
+    py311,  # type: PythonInterpreter
+):
+    # type: (...) -> None
+    target_options.register(parser)
+
+    path_env_var = path_for(py27, py39, py311)
+
+    def dump_complete_platform(
+        name,  # type: str
+        marker_environment,  # type: Dict[str, str]
+        compatible_tags,  # type: List[str]
+        **extra_fields  # type: Any
+    ):
+        # type: (...) -> str
+        path = os.path.join(str(tmpdir), name)
+        with open(path, "w") as fp:
+            json.dump(
+                dict(
+                    marker_environment=marker_environment,
+                    compatible_tags=compatible_tags,
+                    **extra_fields
+                ),
+                fp,
+            )
+        return path
+
+    def assert_local_platforms(
+        complete_platforms,  # type: Iterable[str]
+        expected_complete_platforms,  # type: Iterable[str]
+        expected_interpreter,  # type: Optional[PythonInterpreter]
+        expected_interpreters=None,  # type: Optional[Tuple[PythonInterpreter, ...]]
+    ):
+        # type: (...) -> None
+        args = ["--python-path", path_env_var, "--resolve-local-platforms"]
+        args.extend(
+            itertools.chain.from_iterable(("--complete-platform", p) for p in complete_platforms)
+        )
+        targets = compute_target_configuration(parser, args)
+        expected_complete_platform_objects = tuple(
+            target_options._create_complete_platform(cp) for cp in expected_complete_platforms
+        )
+        assert expected_complete_platform_objects == targets.complete_platforms
+        assert_interpreters_configured(targets, expected_interpreter, expected_interpreters)
+
+    py39_complete = dump_complete_platform(
+        "py39",
+        py39.identity.env_markers.as_dict(),
+        py39.identity.supported_tags.to_string_list(),
+    )
+    py39_extra_complete = dump_complete_platform(
+        "py39_extra",
+        py39.identity.env_markers.as_dict(),
+        py39.identity.supported_tags.to_string_list() + ["py3-none-manylinux_2_9999_x86_64"],
+    )
+
+    py39_extra_complete_prefixed = dump_complete_platform(
+        "py39_extra_prefixed",
+        py39.identity.env_markers.as_dict(),
+        ["py3-none-manylinux_2_9999_x86_64"] + py39.identity.supported_tags.to_string_list(),
+    )
+
+    py39_subset_tags = py39.identity.supported_tags.to_string_list()[:-10]
+    # make the platform different
+    py39_subset_tags[0:2] = py39_subset_tags[0:2:-1]
+    py39_subset_complete = dump_complete_platform(
+        "py39_subset",
+        py39.identity.env_markers.as_dict(),
+        py39_subset_tags,
+    )
+    py311_complete = dump_complete_platform(
+        "py311",
+        py311.identity.env_markers.as_dict(),
+        py311.identity.supported_tags.to_string_list(),
+    )
+    py39999_env_markers = py311.identity.env_markers.as_dict()
+    py39999_env_markers.update(
+        implementation_version="3.9999.0",
+        python_full_version="3.9999.0",
+        python_version="3.9999",
+        sys_platform="linux",
+    )
+    py39999_complete = dump_complete_platform(
+        "other",
+        py39999_env_markers,
+        [
+            "py39999-none-any",
+            "py3-none-any",
+            "py39998-none-any",
+            "py39997-none-any",
+            # you get the idea...
+            "py310-none-any",
+            "py39-none-any",
+            "py38-none-any",
+            "py37-none-any",
+            "py36-none-any",
+            "py35-none-any",
+            "py34-none-any",
+            "py33-none-any",
+            "py32-none-any",
+            "py31-none-any",
+            "py30-none-any",
+        ],
+    )
+
+    # exact match, yay
+    assert_local_platforms(
+        complete_platforms=[py39_complete],
+        expected_complete_platforms=[],
+        expected_interpreter=py39,
+    )
+
+    # the interpreter doesn't support some tags, but that's fine
+    assert_local_platforms(
+        complete_platforms=[py39_extra_complete],
+        expected_complete_platforms=[],
+        expected_interpreter=py39,
+    )
+
+    # the interpreter doesn't support some more specific tags, that is also fine
+    assert_local_platforms(
+        complete_platforms=[py39_extra_complete_prefixed],
+        expected_complete_platforms=[],
+        expected_interpreter=py39,
+    )
+
+    # # the interpreter has some tags it supports that this complete platform does not
+    assert_local_platforms(
+        complete_platforms=[py39_subset_complete],
+        expected_complete_platforms=[py39_subset_complete],
+        expected_interpreter=None,
+    )
+
+    # as above, but now with multiple complete platforms that apply to one interpreter (two
+    # compatible, one not)
+    assert_local_platforms(
+        complete_platforms=[py39_subset_complete, py39_complete, py39_extra_complete],
+        expected_complete_platforms=[py39_subset_complete],
+        expected_interpreter=py39,  # compatible with py38_complete and py38_extra_complete
+    )
+
+    # wildly different
+    assert_local_platforms(
+        complete_platforms=[py39999_complete],
+        expected_complete_platforms=[py39999_complete],
+        expected_interpreter=None,
+    )
+
+    # multiple
+    assert_local_platforms(
+        complete_platforms=[py39_complete, py311_complete],
+        expected_complete_platforms=[],
+        expected_interpreter=py39,
+        expected_interpreters=(py39, py311),
     )
